MigrationError

Enum MigrationError 

pub enum MigrationError {
    NoPath {
        from: u32,
        to: u32,
    },
    StepFailed {
        from: u32,
        to: u32,
        reason: String,
    },
    GapInChain {
        missing: u32,
    },
    FutureVersion {
        found: u32,
        current: u32,
    },
    Deserialization(String),
    Serialization(String),
}
Error during migration.

Variants



NoPath

No migration path exists between the source and target versions.

Fields

from: u32
to: u32


StepFailed

A migration step failed.

Fields

from: u32
to: u32
reason: String


GapInChain

The version chain has a gap (e.g., v1→v3 without v2).

Fields

missing: u32


FutureVersion

The source version is newer than the current version (forward compat).

Fields

found: u32
current: u32


Deserialization(String)

Deserialization failed.



Serialization(String)

Serialization failed.